package com.ynet.life.httpclient;

import com.ynet.life.base.Trace;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.net.URL;
import java.net.URLEncoder;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import javax.net.ssl.SSLHandshakeException;
import org.apache.http.HttpEntity;
import org.apache.http.HttpEntityEnclosingRequest;
import org.apache.http.HttpRequest;
import org.apache.http.HttpResponse;
import org.apache.http.HttpVersion;
import org.apache.http.NameValuePair;
import org.apache.http.NoHttpResponseException;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.HttpRequestRetryHandler;
import org.apache.http.client.ResponseHandler;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.params.BasicHttpParams;
import org.apache.http.params.HttpConnectionParams;
import org.apache.http.params.HttpParams;
import org.apache.http.protocol.HttpContext;
import org.apache.http.util.EntityUtils;

/* loaded from: com_ynet_life_httpclient.jar:com/ynet/life/httpclient/MVCRequestLifePlatUtil.class */
public class MVCRequestLifePlatUtil {
    private static final String CHARSET = "UTF-8";
    public static final String URL_PARAM_DECODECHARSET_UTF8 = "UTF-8";
    private static final String URL_PARAM_CONNECT_FLAG = "&";
    private static final String GENETY = "";
    private static final String CHARSET_GBK = "GBK";
    private static String logName = "MVCRequestLifePlatUtil";
    private static HttpRequestRetryHandler requestRetryHandler = new HttpRequestRetryHandler() { // from class: com.ynet.life.httpclient.MVCRequestLifePlatUtil.1
        @Override // org.apache.http.client.HttpRequestRetryHandler
        public boolean retryRequest(IOException exception, int executionCount, HttpContext context) {
            if (executionCount >= 0) {
                return false;
            }
            if (exception instanceof NoHttpResponseException) {
                return true;
            }
            if (!(exception instanceof SSLHandshakeException) && !(((HttpRequest) context.getAttribute("http.request")) instanceof HttpEntityEnclosingRequest)) {
                return true;
            }
            return false;
        }
    };
    private static ResponseHandler<String> responseHandler = new ResponseHandler<String>() { // from class: com.ynet.life.httpclient.MVCRequestLifePlatUtil.2
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // org.apache.http.client.ResponseHandler
        public String handleResponse(HttpResponse response) throws ClientProtocolException, IOException {
            HttpEntity entity = response.getEntity();
            if (entity != null) {
                String charset = EntityUtils.getContentCharSet(entity) == null ? MVCRequestLifePlatUtil.CHARSET_GBK : EntityUtils.getContentCharSet(entity);
                return new String(EntityUtils.toByteArray(entity), charset);
            }
            return null;
        }
    };

    public static String getReqToPlat(String platUrl, String reqCharSet, String charSet) {
        String reValue = GENETY;
        HttpClient httpclient = getDefaultHttpClient(reqCharSet);
        HttpGet httpget = new HttpGet(platUrl);
        try {
            try {
                Trace.log(logName, "服务平台请求url:" + httpget.getURI());
                HttpEntity entity = httpclient.execute(httpget).getEntity();
                if (entity != null) {
                    reValue = transforEntity2Str(entity, charSet);
                    Trace.log(logName, "服务平台返回结果:".concat(String.valueOf(reValue)));
                }
                try {
                    abortConnection(httpget, httpclient);
                } catch (Exception ignore) {
                    Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore.getMessage());
                }
            } catch (Exception e) {
                Trace.logError(logName, "请求服务平台获得返回结果异常:" + e.getMessage());
            }
            return reValue;
        } finally {
            try {
                abortConnection(httpget, httpclient);
            } catch (Exception ignore2) {
                Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore2.getMessage());
            }
        }
    }

    public static String postReqToPlat(String platUrl, String reqCharSet, String charSet) {
        String reValue = GENETY;
        HttpClient httpclient = getDefaultHttpClient(reqCharSet);
        HttpPost httppost = new HttpPost(platUrl);
        try {
            try {
                Trace.log(logName, "服务平台请求url:" + httppost.getURI());
                HttpEntity entity = httpclient.execute(httppost).getEntity();
                if (entity != null) {
                    reValue = transforEntity2Str(entity, charSet);
                    Trace.log(logName, "服务平台返回结果:".concat(String.valueOf(reValue)));
                }
                try {
                    abortConnection(httppost, httpclient);
                } catch (Exception ignore) {
                    Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore.getMessage());
                }
            } catch (Exception e) {
                Trace.logError(logName, "请求服务平台获得返回结果异常:" + e.getMessage());
            }
            return reValue;
        } finally {
            try {
                abortConnection(httppost, httpclient);
            } catch (Exception ignore2) {
                Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore2.getMessage());
            }
        }
    }

    public static String httpPost(String url, Map<String, String> map, String reqCharSet) {
        HttpPost httpPost = null;
        HttpClient httpClient = null;
        try {
            try {
                try {
                    httpClient = getDefaultHttpClient(reqCharSet);
                    ArrayList<BasicNameValuePair> list = new ArrayList<>();
                    httpPost = new HttpPost(url);
                    for (String keyString : map.keySet()) {
                        list.add(new BasicNameValuePair(keyString, map.get(keyString)));
                    }
                    HttpEntity httpEntity = new UrlEncodedFormEntity(list, reqCharSet);
                    httpPost.setEntity(httpEntity);
                    String transforEntity2Str = transforEntity2Str(httpClient.execute(httpPost).getEntity(), "UTF-8");
                    try {
                        abortConnection(httpPost, httpClient);
                    } catch (Exception ignore) {
                        Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore.getMessage());
                    }
                    return transforEntity2Str;
                } catch (Throwable th) {
                    try {
                        abortConnection(httpPost, httpClient);
                    } catch (Exception ignore2) {
                        Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore2.getMessage());
                    }
                    throw th;
                }
            } catch (ClientProtocolException e) {
                Trace.logError(logName, "请求服务平台获得返回结果转换异常:" + e.getMessage());
                try {
                    abortConnection(httpPost, httpClient);
                    return null;
                } catch (Exception ignore3) {
                    Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore3.getMessage());
                    return null;
                }
            }
        } catch (UnsupportedEncodingException e2) {
            Trace.logError(logName, "请求服务平台获得返回结果转换异常:" + e2.getMessage());
            try {
                abortConnection(httpPost, httpClient);
                return null;
            } catch (Exception ignore4) {
                Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore4.getMessage());
                return null;
            }
        } catch (IOException e3) {
            Trace.logError(logName, "请求服务平台获得返回结果转换异常:" + e3.getMessage());
            throw new RuntimeException("连接失败", e3);
        }
    }

    private static String transforEntity2Str(HttpEntity entity, String charSet) {
        String entityUtils;
        String reValue = GENETY;
        if (entity == null) {
            entityUtils = null;
        } else {
            try {
                entityUtils = EntityUtils.toString(entity, charSet);
            } catch (Exception e) {
                Trace.logError(logName, "请求服务平台获得返回结果转换异常:" + e.getMessage());
            }
        }
        reValue = entityUtils;
        return reValue;
    }

    private static DefaultHttpClient getDefaultHttpClient(String charset) {
        DefaultHttpClient httpclient = new DefaultHttpClient();
        HttpParams params = httpclient.getParams();
        params.setParameter("http.protocol.version", HttpVersion.HTTP_1_1);
        params.setParameter("http.useragent", "Mozilla/4.0 (compatible; MSIE 7.0; MSIE 8.0;MSIE 9.0;Windows NT 5.1)");
        params.setParameter("http.protocol.expect-continue", Boolean.FALSE);
        params.setParameter("http.protocol.content-charset", charset == null ? CHARSET_GBK : charset);
        httpclient.setHttpRequestRetryHandler(requestRetryHandler);
        HttpConnectionParams.setConnectionTimeout(params, 10000);
        HttpConnectionParams.setSoTimeout(params, 20000);
        return httpclient;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v28 */
    /* JADX WARN: Type inference failed for: r0v36, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v37 */
    /* JADX WARN: Type inference failed for: r0v38 */
    public static String getUrlQueryString(Map<String, String> map, String str) {
        if (map == null || map.keySet().size() == 0) {
            return GENETY;
        }
        StringBuffer stringBuffer = new StringBuffer();
        for (String str2 : map.keySet()) {
            if (map.containsKey(str2)) {
                String str3 = map.get(str2);
                UnsupportedEncodingException unsupportedEncodingException = str3 != null ? str3 : GENETY;
                String str4 = unsupportedEncodingException;
                try {
                    unsupportedEncodingException = URLEncoder.encode(str4, str);
                    str4 = unsupportedEncodingException;
                } catch (UnsupportedEncodingException e) {
                    unsupportedEncodingException.printStackTrace();
                }
                stringBuffer.append(str2).append("=").append(str4).append(URL_PARAM_CONNECT_FLAG);
            }
        }
        String stringBuffer2 = stringBuffer.toString();
        if (URL_PARAM_CONNECT_FLAG.equals(new StringBuilder().append(stringBuffer2.charAt(stringBuffer2.length() - 1)).toString())) {
            stringBuffer2 = stringBuffer2.substring(0, stringBuffer2.length() - 1);
        }
        return stringBuffer2;
    }

    public static String httpGet(String url, Map<String, String> params, String reqCharSet) {
        HttpGet httpGet = null;
        HttpClient httpClient = null;
        try {
            try {
                try {
                    httpClient = getDefaultHttpClient(reqCharSet);
                    httpGet = new HttpGet(url);
                    if (params != null && params.size() > 0) {
                        HttpParams param = new BasicHttpParams();
                        for (String keyString : params.keySet()) {
                            param.setParameter(keyString, params.get(keyString));
                        }
                        httpGet.setParams(param);
                    }
                    HttpEntity resEntity = httpClient.execute(httpGet).getEntity();
                    httpGet.releaseConnection();
                    String transforEntity2Str = transforEntity2Str(resEntity, "UTF-8");
                    try {
                        abortConnection(httpGet, httpClient);
                    } catch (Exception ignore) {
                        Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore.getMessage());
                    }
                    return transforEntity2Str;
                } catch (Throwable th) {
                    try {
                        abortConnection(httpGet, httpClient);
                    } catch (Exception ignore2) {
                        Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore2.getMessage());
                    }
                    throw th;
                }
            } catch (IOException e) {
                Trace.logError(logName, "请求服务平台获得返回结果转换异常:" + e.getMessage());
                throw new RuntimeException("连接服务平台失败", e);
            }
        } catch (UnsupportedEncodingException e2) {
            Trace.logError(logName, "请求服务平台获得返回结果转换异常:" + e2.getMessage());
            try {
                abortConnection(httpGet, httpClient);
                return null;
            } catch (Exception ignore3) {
                Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore3.getMessage());
                return null;
            }
        } catch (ClientProtocolException e3) {
            Trace.logError(logName, "请求服务平台获得返回结果转换异常:" + e3.getMessage());
            try {
                abortConnection(httpGet, httpClient);
                return null;
            } catch (Exception ignore4) {
                Trace.logError(logName, "请求服务平台获得返回结果异常:" + ignore4.getMessage());
                return null;
            }
        }
    }

    private static void abortConnection(HttpRequestBase hrb, HttpClient httpclient) {
        if (hrb != null) {
            hrb.abort();
        }
        if (httpclient != null) {
            httpclient.getConnectionManager().shutdown();
        }
    }

    private static KeyStore createKeyStore(URL url, String password) throws KeyStoreException, NoSuchAlgorithmException, CertificateException, IOException {
        if (url == null) {
            throw new IllegalArgumentException("Keystore url may not be null");
        }
        KeyStore keystore = KeyStore.getInstance(KeyStore.getDefaultType());
        InputStream is = null;
        try {
            is = url.openStream();
            keystore.load(is, password != null ? password.toCharArray() : null);
            if (is != null) {
                is.close();
            }
            return keystore;
        } catch (Throwable th) {
            if (is != null) {
                is.close();
            }
            throw th;
        }
    }

    private static List<NameValuePair> getParamsList(Map<String, String> paramsMap) {
        if (paramsMap == null || paramsMap.size() == 0) {
            return null;
        }
        List<NameValuePair> params = new ArrayList<>();
        for (Map.Entry<String, String> map : paramsMap.entrySet()) {
            params.add(new BasicNameValuePair(map.getKey().toString(), map.getValue().toString()));
        }
        return params;
    }
}
